package com.abi.qms.platform.controller.console;

import com.abi.platform.Base.BaseResponse;
import com.abi.qms.platform.dto.req.AddFlowQueryRecordReq;
import com.abi.qms.platform.dto.req.ExportFlowQueryRecordReq;
import com.abi.qms.platform.dto.req.PageListFlowQueryRecordReq;
import com.abi.qms.platform.dto.res.ExportFlowQueryRecordRes;
import com.abi.qms.platform.dto.res.GetFlowQueryRecordInfo;
import com.abi.qms.platform.dto.res.PageListFlowQueryRecordRes;
import com.abi.qms.platform.service.IFlowQueryRecordService;
import com.abi.task.common.excel.ExcelInputFactory;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 流向查询记录 Controller
 *
 * @author ZhangZhao
 * @date 2021-07-21
 */
@Slf4j
@Api(value = "流向查询记录 控制器", tags = {"流向查询记录 管理"})
@RestController
@RequestMapping("/flow/record")
public class FlowQueryRecordController {


    @Autowired
    private IFlowQueryRecordService flowQueryRecordService;


    @ApiOperation("新增流向查询记录")
    @GetMapping("/add")
    public BaseResponse addFlowQueryRecord(@Validated AddFlowQueryRecordReq addReq) {
        flowQueryRecordService.addFlowQueryRecord(addReq);
        return BaseResponse.create();
    }


    /**
     * 查询流向查询记录 列表
     */
    @ApiOperation("查询流向查询记录 列表")
    @GetMapping("/page/list")
    public BaseResponse<PageListFlowQueryRecordRes> pageList(@Validated PageListFlowQueryRecordReq pageListReq) {
        PageListFlowQueryRecordRes res = flowQueryRecordService.pageListQuery(pageListReq);
        return BaseResponse.create(res);
    }


    /**
     * 获取流向查询记录 详细信息
     */
    @ApiOperation("获取流向查询记录 详细信息")
    @GetMapping(value = "/getInfo")
    public BaseResponse<GetFlowQueryRecordInfo> getInfo(@NotNull(message = "主键不能为空") Long id) {
        GetFlowQueryRecordInfo recordInfo = flowQueryRecordService.getDetailsById(id);
        return BaseResponse.create(recordInfo);
    }


    @ResponseBody
    @ApiOperation(value = "导出")
    @GetMapping("export")
    public void export(@Validated ExportFlowQueryRecordReq req, HttpServletResponse response) {
        List<ExportFlowQueryRecordRes> resList = flowQueryRecordService.export(req);
        ExcelInputFactory.downloadExcelData("流向查询记录", response, resList, ExportFlowQueryRecordRes.class);
    }


}
