package com.abi.qms.platform.controller.wx;

import com.abi.platform.Base.BaseResponse;
import com.abi.qms.platform.dto.req.WxGetBoxCodeReq;
import com.abi.qms.platform.dto.req.WxGetInvisibleCodeReq;
import com.abi.qms.platform.dto.req.WxGetStackCodeReq;
import com.abi.qms.platform.dto.res.WxGetBoxCodeRes;
import com.abi.qms.platform.dto.res.WxGetInvisibleCodeRes;
import com.abi.qms.platform.dto.res.WxGetStackCodeRes;
import com.abi.qms.platform.service.FlowQueryService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 微信箱码垛码查询 Controller
 *
 * @author WeiganCai
 * @date 2021-08-19
 */
@Slf4j
@RestController
@Api(tags = "微信箱码垛码查询")
@RequestMapping("/wx/flowQuery")
public class WxFlowQueryController {
    @Autowired
    private FlowQueryService flowQueryService;

    @ApiOperation("箱码查询")
    @GetMapping("/boxCode")
    public BaseResponse<WxGetBoxCodeRes> wxBoxCode (@Validated WxGetBoxCodeReq req) {
        WxGetBoxCodeRes res = flowQueryService.wxBoxCode(req);
        return BaseResponse.create(res);
    }

    @ApiOperation("隐形码模糊查询")
    @GetMapping("/invisibleCode/like")
    public BaseResponse<WxGetInvisibleCodeRes> invisibleCode (@Validated WxGetInvisibleCodeReq req) {
        WxGetInvisibleCodeRes res = flowQueryService.WxInvisibleCode(req);
        return BaseResponse.create(res);
    }

    @ApiOperation("垛码查询")
    @GetMapping("/stackCode")
    public BaseResponse<WxGetStackCodeRes> stackCode(@Validated WxGetStackCodeReq req) {
        WxGetStackCodeRes res = flowQueryService.wxStackCode(req);
        return BaseResponse.create(res);
    }


}
