package com.abi.qms.platform.dto.req;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;
import org.jetbrains.annotations.NotNull;

import javax.validation.constraints.NotBlank;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;

/**
 * @author: zhang zhao
 * @date: 2021/7/2716:38
 * @description: 新增流向查询记录入参
 */
@Data
@ApiModel
@NoArgsConstructor
public class AddFlowQueryRecordReq {

    /**
     * 流向状态 1-正常  2-异常
     */
    @ApiModelProperty(value = "流向状态 1-正常  2-异常 ", required = true)
    @NotNull
    private Integer flowStatus;

    /**
     * 查询类型 1-箱码查询 2-托盘码查询
     */
    @ApiModelProperty(value = "查询类型 1-箱码查询 2-托盘码查询", required = true)
    @NotNull
    private Integer queryType;

    /**
     * 箱码
     */
    @ApiModelProperty("箱码 查询类型为箱码时必传")
    private String boxCode;

    /**
     * 托盘码
     */
    @ApiModelProperty("托盘码 查询类型为托盘码时必传")
    private String trayCode;

    /**
     * 品牌
     */
    @ApiModelProperty(value = "品牌CODE", required = true)
    @NotBlank
    private String brandCode;

    /**
     * 品牌
     */
    @ApiModelProperty(value = "品牌名称", required = true)
    @NotBlank
    private String brandName;

    /**
     * SKU-CODE
     */
    @ApiModelProperty(value = "SKU-CODE", required = true)
    @NotBlank
    private String skuCode;


    @ApiModelProperty(value = "生产批次")
    private String productionBatch;

    @ApiModelProperty(value = "生产日期")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private LocalDateTime productionTime;

    /**
     * 查询平台
     */
    @ApiModelProperty(value = "查询平台 1-微信  2-后台", required = true)
    @NotBlank
    private Integer queryPlatform;


    /**
     * 查询地址
     */
    @ApiModelProperty(value = "查询地址 查询平台为微信时必传")
    private String queryAddress;



    /**
     * 异常节点CODE-流出
     */
    @ApiModelProperty(value = "异常节点CODE-流入 流向状态为异常时必传")
    private Long abnormalInNodeCode;

    /**
     * 异常节点名称-流出
     */
    @ApiModelProperty(value = "异常节点名称-流入 流向状态为异常时必传")
    private String abnormalInNodeName;


    /**
     * 异常节点CODE-流出
     */
    @ApiModelProperty(value = "异常节点CODE-流出 流向状态为异常时必传")
    private Long abnormalOutNodeCode;


    /**
     * 异常节点名称-流出
     */
    @ApiModelProperty(value = "异常节点名称-流出 流向状态为异常时必传")
    private String abnormalOutNodeName;


    /**
     * 箱垛信息
     */
    @ApiModelProperty(value = "箱垛信息")
    private BoxStackBean boxStackInfo;

    /**
     * 流向信息列表
     */
    @ApiModelProperty(value = "流向信息列表")
    private List<FlowBean> flowList;


    /**
     * 箱垛信息
     */
    @Data
    @Accessors(chain = true)
    public static class BoxStackBean implements Serializable {
        @Schema(name = "箱码")
        private String boxCode;

        @Schema(name = "隐形码")
        private String invisibleCode;

        @Schema(name = "原始托盘码")
        private String originalStackCode;

        @Schema(name = "原始堆垛时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime originalStackTime;

        @Schema(name = "最新托盘码")
        private String newestStackCode;

        @Schema(name = "最新堆垛时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime newestStackTime;
    }



    /**
     * 流向信息
     */
    @Data
    @Accessors(chain = true)
    public static class FlowBean implements Serializable {
        @Schema(name = "节点标识")
        private Long nodeId;

        @Schema(name = "节点名称")
        private String nodeName;

        @Schema(name = "节点状态")
        private Integer nodeStatus;

        @Schema(name = "是否拆垛")
        private Integer isSplit;

        @Schema(name = "拆垛托盘码")
        private String splitStackCode;

        @Schema(name = "入库时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime inStorageTime;

        @Schema(name = "出库时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime outStorageTime;
    }



}
