package com.abi.qms.platform.dto.res;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.experimental.Accessors;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;

/**
 * 箱码查询出参
 * TODO 测试使用，待流向查询接口完成后，根据实际情况调整结构
 *
 * @author WeiganCai
 * @date: 2021-08-02
 */
@Data
@ApiModel
public class GetBoxCodeRes implements Serializable {
    @Schema(name = "SKU信息")
    private SkuBean sku;

    @Schema(name = "案件信息")
    private InspectionCaseBean inspectionCase;

    @Schema(name = "流向信息")
    private List<FlowBean> flowList;

    @Schema(name = "箱垛信息")
    private BoxStackBean boxStack;


    /**
     * SKU信息
     */
    @Data
    @Accessors(chain = true)
    public static class SkuBean implements Serializable {
        @Schema(name = "品牌编码")
        private String brandCode;

        @Schema(name = "品牌名称")
        private String brandName;

        @Schema(name = "SKUId")
        private String skuId;

        @Schema(name = "SKU名称")
        private String skuName;

        @Schema(name = "生产批次")
        private String productionBatch;

        @Schema(name = "生产日期")
        @JsonFormat(pattern = "yyyy-MM-dd")
        private LocalDateTime productionTime;
    }

    /**
     * 案件信息
     */
    @Data
    @Accessors(chain = true)
    public static class InspectionCaseBean implements Serializable {
        @Schema(name = "案件编号")
        private String caseNumber;

        @Schema(name = "案件名称")
        private String caseName;
    }

    /**
     * 流向信息
     */
    @Data
    @Accessors(chain = true)
    public static class FlowBean implements Serializable {
        @Schema(name = "节点标识")
        private Long nodeId;

        @Schema(name = "节点名称")
        private String nodeName;

        @Schema(name = "节点状态")
        private Integer nodeStatus;

        @Schema(name = "异常类型 0-无异常 1-流入异常 2-流出异常")
        private Integer abnormalType = 0;

        @Schema(name = "是否拆垛")
        private Integer isSplit;

        @Schema(name = "拆垛托盘码")
        private String splitStackCode;

        @Schema(name = "入库时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime inStorageTime;

        @Schema(name = "出库时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime outStorageTime;
    }

    /**
     * 箱垛信息
     */
    @Data
    @Accessors(chain = true)
    public static class BoxStackBean implements Serializable {
        @Schema(name = "箱码")
        private String boxCode;

        @Schema(name = "隐形码")
        private String invisibleCode;

        @Schema(name = "原始托盘码")
        private String originalStackCode;

        @Schema(name = "原始堆垛时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime originalStackTime;

        @Schema(name = "最新托盘码")
        private String newestStackCode;

        @Schema(name = "最新堆垛时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime newestStackTime;
    }
}
