package com.abi.qms.platform.dto.res;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.experimental.Accessors;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;

/**
 * @author: zhang zhao
 * @date: 2021/7/2720:20
 * @description: 获取查询流向记录详情信息出参对象
 */
@Data
@ApiModel
public class GetFlowQueryRecordInfo implements Serializable {

    /**
     * 编号
     */
    @ApiModelProperty(value = "编号")
    private Long number;


    /**
     * 流向状态
     */
    @ApiModelProperty(value = "流向状态")
    private String flowStatus;


    /**
     * 查询平台
     */
    @ApiModelProperty(value = "查询平台")
    private String queryPlatform;

    /**
     * 查询人
     */
    @ApiModelProperty(value = "查询人")
    private String queryUserName;

    /**
     * 查询地址
     */
    @ApiModelProperty(value = "查询地址")
    private String queryAddress;

    /**
     * 查询时间
     */
    @ApiModelProperty(value = "查询时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime queryTime;


    /**
     * SKU
     */
    @ApiModelProperty(value = "SKU信息")
    private SkuBean skuInfo;


    /**
     * 箱垛信息
     */
    @ApiModelProperty(value = "箱垛信息")
    private BoxStackBean boxStack;


    /**
     * 流向信息
     */
    @ApiModelProperty(value = "流向信息列表")
    private List<FlowBean> flowInfoList;

    /**
     * SKU信息
     */
    @Data
    @Accessors(chain = true)
    public static class SkuBean implements Serializable {
        @Schema(name = "品牌编码")
        private String brandCode;

        @Schema(name = "品牌名称")
        private String brandName;

        @Schema(name = "SKUId")
        private String skuId;

        @Schema(name = "SKU名称")
        private String skuName;

        @Schema(name = "生产批次")
        private String productionBatch;

        @Schema(name = "生产日期")
        @JsonFormat(pattern = "yyyy-MM-dd")
        private LocalDateTime productionTime;
    }


    /**
     * 箱垛信息
     */
    @Data
    @Accessors(chain = true)
    public static class BoxStackBean implements Serializable {
        @Schema(name = "箱码")
        private String boxCode;

        @Schema(name = "隐形码")
        private String invisibleCode;

        @Schema(name = "原始托盘码")
        private String originalStackCode;

        @Schema(name = "原始堆垛时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime originalStackTime;

        @Schema(name = "最新托盘码")
        private String newestStackCode;

        @Schema(name = "最新堆垛时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime newestStackTime;
    }


    /**
     * 流向信息
     */
    @Data
    @Accessors(chain = true)
    public static class FlowBean implements Serializable {
        @Schema(name = "节点标识")
        private Long nodeId;

        @Schema(name = "节点名称")
        private String nodeName;

        @Schema(name = "节点状态")
        private Integer nodeStatus;


        @Schema(name = "是否拆垛")
        private Integer isSplit;

        @Schema(name = "拆垛托盘码")
        private String splitStackCode;

        @Schema(name = "入库时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime inStorageTime;

        @Schema(name = "出库时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime outStorageTime;
    }


}
