package com.abi.qms.platform.service.impl;


import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import com.abi.qms.platform.dao.entity.FlowQueryRecord;
import com.abi.qms.platform.dao.entity.FlowQueryRecordBoxStack;
import com.abi.qms.platform.dao.entity.FlowQueryRecordFlow;
import com.abi.qms.platform.dao.enums.FlowQueryTypeEnum;
import com.abi.qms.platform.dao.enums.FlowStatusEnum;
import com.abi.qms.platform.dao.enums.ReqChannelTypeEnum;
import com.abi.qms.platform.dao.mapper.FlowQueryRecordBoxStackMapper;
import com.abi.qms.platform.dao.mapper.FlowQueryRecordFlowMapper;
import com.abi.qms.platform.dao.mapper.FlowQueryRecordMapper;
import com.abi.qms.platform.dao.vo.result.FlowQueryRecordInfoVo;
import com.abi.qms.platform.dao.vo.result.ListFlowQueryRecordVO;
import com.abi.qms.platform.dao.vo.result.WxListFlowQueryRecordVO;
import com.abi.qms.platform.dto.req.AddFlowQueryRecordReq;
import com.abi.qms.platform.dto.req.ExportFlowQueryRecordReq;
import com.abi.qms.platform.dto.req.PageListFlowQueryRecordReq;
import com.abi.qms.platform.dto.req.WxPageListFlowQueryRecordReq;
import com.abi.qms.platform.dto.res.ExportFlowQueryRecordRes;
import com.abi.qms.platform.dto.res.GetFlowQueryRecordInfo;
import com.abi.qms.platform.dto.res.PageListFlowQueryRecordRes;
import com.abi.qms.platform.dto.res.WxPageListFlowQueryRecordRes;
import com.abi.qms.platform.feign.SkuFeign;
import com.abi.qms.platform.infrastructure.util.AssertUtil;
import com.abi.qms.platform.infrastructure.util.PageUtil;
import com.abi.qms.platform.service.FlowQueryRecordBoxStackService;
import com.abi.qms.platform.service.FlowQueryRecordFlowService;
import com.abi.qms.platform.service.IFlowQueryRecordService;
import com.abi.task.common.utils.PojoConverterUtils;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.stream.Collectors;

/**
 * 流向查询记录 Service业务层处理
 *
 * @author: ZhangZhao
 * @date: 2021-07-21
 */
@Service
public class FlowQueryRecordServiceImpl implements IFlowQueryRecordService {

    @Autowired
    private FlowQueryRecordMapper flowQueryRecordMapper;

    @Autowired
    private FlowQueryRecordFlowMapper queryRecordFlowMapper;

    @Autowired
    private FlowQueryRecordBoxStackMapper queryRecordBoxStackMapper;

    @Autowired
    private SkuFeign skuFeign;

    /**
     * 分页查询列表
     *
     * @param pageListReq 查询条件
     * @return 查询结果
     */
    @Override
    public PageListFlowQueryRecordRes pageListQuery(PageListFlowQueryRecordReq pageListReq) {

        IPage<ListFlowQueryRecordVO> pageResult = flowQueryRecordMapper.pageListQuery(PageUtil.createPage(pageListReq), pageListReq);

        List<ListFlowQueryRecordVO> flowQueryRecordVOList = pageResult.getRecords();

        //转换类型
        List<PageListFlowQueryRecordRes.FlowQueryRecordBean> flowQueryRecordBeanList = flowQueryRecordVOList.stream()
                .parallel().map(s -> {
                    // 查询sku
                    String skuCode = s.getSkuCode();
                    if (StringUtils.isNotBlank(skuCode)) {
                        SkuFeign.Sku sku = skuFeign.getSkuByCode(skuCode);
                        if (sku != null) {
                            s.setSkuName(sku.getSkuName());
                        }
                    }

                    PageListFlowQueryRecordRes.FlowQueryRecordBean flowQueryRecordBean = new PageListFlowQueryRecordRes.FlowQueryRecordBean();
                    BeanUtil.copyProperties(s, flowQueryRecordBean);

                    //流向状态
                    String flowStatusName = FlowStatusEnum.getName(s.getFlowStatus());
                    flowQueryRecordBean.setFlowStatus(flowStatusName);

                    //查询平台
                    String channelName = ReqChannelTypeEnum.getName(s.getQueryPlatform());
                    flowQueryRecordBean.setQueryPlatform(channelName);

                    return flowQueryRecordBean;
                }).collect(Collectors.toList());

        //封装出参
        PageListFlowQueryRecordRes flowQueryRecordRes = new PageListFlowQueryRecordRes();

        //放入分页信息
        PageUtil.copyPageInfo(flowQueryRecordRes, pageResult);
        flowQueryRecordRes.setFlowQueryRecordList(flowQueryRecordBeanList);

        return flowQueryRecordRes;
    }


    /**
     * 新增流向查询记录
     *
     * @param addReq 新增请求
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void addFlowQueryRecord(AddFlowQueryRecordReq addReq) {
        //校验请求内容
        validatedFlowQueryRecordReq(addReq);
        //值拷贝
        FlowQueryRecord flowQueryRecord = new FlowQueryRecord();
        BeanUtil.copyProperties(addReq, flowQueryRecord);
        //保存信息
        flowQueryRecordMapper.insert(flowQueryRecord);

        Long flowQueryRecordId = flowQueryRecord.getId();

        //保存箱垛信息
        AddFlowQueryRecordReq.BoxStackBean boxStackInfo = addReq.getBoxStackInfo();
        FlowQueryRecordBoxStack flowQueryRecordBoxStack = new FlowQueryRecordBoxStack();
        BeanUtil.copyProperties(boxStackInfo, flowQueryRecordBoxStack);
        flowQueryRecordBoxStack.setFlowQueryRecordId(flowQueryRecordId);
        queryRecordBoxStackMapper.insert(flowQueryRecordBoxStack);

        //保存关联流向信息

        List<AddFlowQueryRecordReq.FlowBean> flowList = addReq.getFlowList();

        //转换类型
        List<FlowQueryRecordFlow> flowQueryRecordFlows = flowList.stream()
                .parallel().map(s -> {
                    FlowQueryRecordFlow flowQueryRecordFlow = new FlowQueryRecordFlow();
                    BeanUtil.copyProperties(s, flowQueryRecordFlow);
                    flowQueryRecordFlow.setFlowQueryRecordId(flowQueryRecordId);
                    return flowQueryRecordFlow;
                }).collect(Collectors.toList());

        queryRecordFlowMapper.insertBatch(flowQueryRecordFlows);


    }


    /**
     * 根据ID获取记录详情
     *
     * @param id 指定ID
     * @return 详情信息
     */
    @Override
    public GetFlowQueryRecordInfo getDetailsById(final Long id) {
        FlowQueryRecordInfoVo flowQueryRecordInfoVo = flowQueryRecordMapper.getDetailsById(id);
        AssertUtil.isNull(flowQueryRecordInfoVo, "未找到指定记录！");
        //查询sku
        String skuCode = flowQueryRecordInfoVo.getSkuCode();
        if (StringUtils.isNotBlank(skuCode)) {
            SkuFeign.Sku sku = skuFeign.getSkuByCode(skuCode);
            if (sku != null) {
                flowQueryRecordInfoVo.setSkuName(sku.getSkuName());
            }
        }
        //转换类型
        GetFlowQueryRecordInfo getFlowQueryRecordInfo = new GetFlowQueryRecordInfo();
        BeanUtil.copyProperties(flowQueryRecordInfoVo, getFlowQueryRecordInfo);
        //编号
        getFlowQueryRecordInfo.setNumber(flowQueryRecordInfoVo.getId());
        //流向状态
        Integer flowStatus = flowQueryRecordInfoVo.getFlowStatus();
        String flowStatusName = FlowStatusEnum.getName(flowStatus);
        getFlowQueryRecordInfo.setFlowStatus(flowStatusName);

        //SKU
        GetFlowQueryRecordInfo.SkuBean skuBean = new GetFlowQueryRecordInfo.SkuBean();
        skuBean.setSkuId(flowQueryRecordInfoVo.getSkuCode());
        skuBean.setSkuName(flowQueryRecordInfoVo.getSkuName());
        skuBean.setBrandCode(flowQueryRecordInfoVo.getBrandCode());
        skuBean.setBrandName(flowQueryRecordInfoVo.getBrandName());
        skuBean.setProductionBatch(flowQueryRecordInfoVo.getProductionBatch());
        skuBean.setProductionTime(flowQueryRecordInfoVo.getProductionTime());
        getFlowQueryRecordInfo.setSkuInfo(skuBean);

        //箱垛信息
        QueryWrapper<FlowQueryRecordBoxStack> boxStackQW = new QueryWrapper<>();
        boxStackQW.eq("flow_query_record_id", id);
        FlowQueryRecordBoxStack flowQueryRecordBoxStack = queryRecordBoxStackMapper.selectOne(boxStackQW);
        GetFlowQueryRecordInfo.BoxStackBean boxStackBean = new GetFlowQueryRecordInfo.BoxStackBean();
        BeanUtil.copyProperties(flowQueryRecordBoxStack, boxStackBean);
        getFlowQueryRecordInfo.setBoxStack(boxStackBean);

        //流向信息
        QueryWrapper<FlowQueryRecordFlow> flowQueryRecordFlowQW = new QueryWrapper<>();
        flowQueryRecordFlowQW.eq("flow_query_record_id", id);
        List<FlowQueryRecordFlow> flowQueryRecordFlows = queryRecordFlowMapper.selectList(flowQueryRecordFlowQW);
        List<GetFlowQueryRecordInfo.FlowBean> flowBeans = PojoConverterUtils.copyList(flowQueryRecordFlows, GetFlowQueryRecordInfo.FlowBean.class);
        getFlowQueryRecordInfo.setFlowInfoList(flowBeans);

        return getFlowQueryRecordInfo;
    }


    /**
     * 导出列表数据
     *
     * @param req 查询条件
     * @return 数据列表
     */
    @Override
    public List<ExportFlowQueryRecordRes> export(ExportFlowQueryRecordReq req) {

        List<ListFlowQueryRecordVO> list = flowQueryRecordMapper.queryList(req);

        //转换类型
        List<ExportFlowQueryRecordRes> flowQueryRecordBeanList = list.stream()
                .parallel().map(s -> {
                    // 查询sku
                    String skuCode = s.getSkuCode();
                    if (StringUtils.isNotBlank(skuCode)) {
                        SkuFeign.Sku sku = skuFeign.getSkuByCode(skuCode);
                        if (sku != null) {
                            s.setSkuName(sku.getSkuName());
                        }
                    }

                    ExportFlowQueryRecordRes flowQueryRecordBean = new ExportFlowQueryRecordRes();
                    BeanUtil.copyProperties(s, flowQueryRecordBean);

                    //流向状态
                    String flowStatusName = FlowStatusEnum.getName(s.getFlowStatus());
                    flowQueryRecordBean.setFlowStatus(flowStatusName);

                    //查询平台
                    String channelName = ReqChannelTypeEnum.getName(s.getQueryPlatform());
                    flowQueryRecordBean.setQueryPlatform(channelName);

                    return flowQueryRecordBean;
                }).collect(Collectors.toList());

        return flowQueryRecordBeanList;
    }

    /**
     * 微信分页查询列表
     */
    @Override
    public WxPageListFlowQueryRecordRes wxPageListQuery(WxPageListFlowQueryRecordReq req) {
        IPage<WxListFlowQueryRecordVO> pageResult = flowQueryRecordMapper.wxPageListQuery(PageUtil.createPage(req),req);
        List<WxListFlowQueryRecordVO> recordList = pageResult.getRecords();
        recordList.forEach(record -> {
            String skuCode = record.getSkuCode();
            if (StringUtils.isNotBlank(skuCode)) {
                SkuFeign.Sku sku = skuFeign.getSkuByCode(skuCode);
                if (sku != null) {
                    record.setSkuName(sku.getSkuName());
                }
            }
        });

        WxPageListFlowQueryRecordRes res = new WxPageListFlowQueryRecordRes();
        PageUtil.copyPageInfo(res, pageResult);
        List<WxPageListFlowQueryRecordRes.FlowQueryRecordBean> flowQueryRecordBeanList = PojoConverterUtils.copyList(recordList, WxPageListFlowQueryRecordRes.FlowQueryRecordBean.class);
        res.setFlowQueryRecordList(flowQueryRecordBeanList);

        return res;
    }

    /**
     * 校验-新增流向查询记录请求内容
     *
     * @param addReq 请求内容
     */
    private static void validatedFlowQueryRecordReq(AddFlowQueryRecordReq addReq) {
        //流向状态
        Integer flowStatus = addReq.getFlowStatus();
        AssertUtil.isNull(flowStatus, "请指明 流向状态！");

        //查询平台
        Integer queryPlatform = addReq.getQueryPlatform();
        AssertUtil.isNull(queryPlatform, "请指明 查询平台！");

        //查询类型
        Integer queryType = addReq.getQueryType();
        AssertUtil.isNull(queryType, "请指明 查询类型！");

        //箱码
        if (FlowQueryTypeEnum.BOX_CODE.is(queryType)) {
            String boxCode = addReq.getBoxCode();
            AssertUtil.isMeets(boxCode, StrUtil::isNotBlank, "箱码查询时  箱码不能为空！");
        }


        //托盘码
        if (FlowQueryTypeEnum.TRAY_CODE.is(queryType)) {
            String trayCode = addReq.getTrayCode();
            AssertUtil.isMeets(trayCode, StrUtil::isNotBlank, "托盘码查询时  托盘码不能为空！");
        }


        //异常节点
        if (FlowStatusEnum.ABNORMAL.is(flowStatus)) {
            Long nodeIn = addReq.getAbnormalInNodeCode();
            AssertUtil.isNull(nodeIn, "流向状态为异常时  必须指明异常流入节点！");

            Long nodeOut = addReq.getAbnormalOutNodeCode();
            AssertUtil.isNull(nodeOut, "流向状态为异常时  必须指明异常流出节点！");
        }

    }


}
