package com.abi.qms.platform;

import com.abi.qms.platform.dao.tablestore.entity.QrCode;
import com.abi.qms.platform.infrastructure.util.AsyncTableStoreUtil;
import com.abi.qms.platform.service.QrBoxMappingService;
import com.abi.task.common.tablestore.TableStorePlusUtils;
import com.abi.task.common.tablestore.common.TableStoreEntity;
import com.abi.task.common.tablestore.common.TableStoreReq;
import com.abi.task.common.tablestore.common.TableStoreRes;
import com.abi.task.common.tablestore.entity.DemoEntity;
import lombok.extern.slf4j.Slf4j;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

@SpringBootTest
@Slf4j
public class TableStorePlusTest {

    @Autowired
    private TableStorePlusUtils tableStorePlusUtils;

    @Autowired
    private AsyncTableStoreUtil asyncTableStoreUtil;

    @Autowired
    private QrBoxMappingService qrBoxMappingService;

    @Test
    public void testAddRow() {
        DemoEntity entity = new DemoEntity();
        entity.setQrCode("10293827182717");
        entity.setPayAmount(990.12);
        entity.setCurrentTime(LocalDateTime.now());
        entity.setUserId(10001L);
        entity.setActiveCount(33);
        entity.setIsDog(false);

        DemoEntity entity2 = new DemoEntity();
        entity2.setQrCode("10293827182716");
        entity2.setPayAmount(990.12);
        entity2.setCurrentTime(LocalDateTime.now());
        entity2.setUserId(10001L);
        entity2.setActiveCount(33);
        entity2.setIsDog(false);

        tableStorePlusUtils.putRow(Arrays.asList(entity, entity2));
    }

    @Test
    public void testBatchAddRow(){
        List<TableStoreEntity> qrCodeList = new ArrayList<>();
        for(int i=0;i<20000;i++){
            QrCode qrCode = new QrCode();
            qrCode.setCode(System.currentTimeMillis()+"-"+i);
            qrCode.setPackageId(0L);
            qrCode.setBatchNumberId(0L);
            qrCode.setCreateTime(LocalDateTime.now());
            qrCode.setCodeIndex(0L);
            qrCode.setQrRepertoryColumnId(0L);
            qrCode.setInvalid(0);
            qrCodeList.add(qrCode);
        }

        tableStorePlusUtils.putRow(qrCodeList);
    }

    @Test
    public void testGetRow() {
        QrCode entity = tableStorePlusUtils.selectOne(QrCode.class, "1397521498780426242");
        Long codeIndex = entity.getCodeIndex();
        log.info("======" + codeIndex);
    }

    //按索引范围匹配
    @Test
    public void queryRowsRange(){
        TableStoreReq<QrCode> req = TableStoreReq.build(QrCode.class,"codeIndex")
                .range(1,100)
                .page(1,15)
                .isDesc();
        //调用查询
        TableStoreRes<QrCode> res = tableStorePlusUtils.selectList(req);

        List<QrCode> qrCodeList = res.getEntityList();

        //打印
        for(QrCode qrCode:qrCodeList){
            log.info(qrCode.toString());
        }
    }

    //按索引精确匹配
    @Test
    public void queryRowsEqual(){
        TableStoreReq<QrCode> req = TableStoreReq.build(QrCode.class,"packageId")
                .eq("1")
                .page(1,3)
                .isNeedTotalCount();

        TableStoreRes<QrCode> res = tableStorePlusUtils.selectList(req);

        List<QrCode> qrCodeList = res.getEntityList();

        //打印
        for(QrCode qrCode:qrCodeList){
            log.info(qrCode.toString());
        }
        log.info("total count----------->");
        log.info(String.valueOf(res.getTotalCount()));
    }

    @Test
    public void testDeleteRow() {
        tableStorePlusUtils.deleteRow(DemoEntity.class, "10293827182717");
    }

    @Test
    public void testAsyncPut() {
        List<String> codeList = new ArrayList<>();
        codeList.add("5lsi4rHdi3V1");
        codeList.add("5ls0rL8vL7A1");
        codeList.add("5ls5I3IwU8R1");
        codeList.add("5ls129h44eD1");
        codeList.add("5ls700E97h91");
        codeList.add("5ls7718P6061");
        codeList.add("5lsM2193C881");
        codeList.add("5lsrk95846L1");
        codeList.add("5lsK79Xzg841");
        codeList.add("5lsap2iM07D1");

        List<QrCode> qrCodeList = new ArrayList<>();
        for(String code:codeList){
            QrCode qrCode = new QrCode();
            qrCode.setCode(code);
            qrCode.setQrBoxMappingId(12345L);
            qrCodeList.add(qrCode);
        }

        tableStorePlusUtils.updateRow(qrCodeList,"qrBoxMappingId");

    }

    @Test
    public void addQrBoxMappingByFileUpload() {
//        List<String> codeList = new ArrayList<>();
//        codeList.add("5lsi4rHdi3V1");
//        codeList.add("5ls0rL8vL7A1");
//        codeList.add("5ls5I3IwU8R1");
//        codeList.add("5ls129h44eD1");
//        codeList.add("5ls700E97h91");
//        codeList.add("5ls7718P6061");
//        codeList.add("5lsM2193C881");
//        codeList.add("5lsrk95846L1");
//        codeList.add("5lsK79Xzg841");
//        codeList.add("5lsap2iM07D1");
//
//        qrBoxMappingService.addQrBoxMappingByFileUpload(codeList,1234567L);
//
//        try {
//            Thread.sleep(5000L);
//        } catch (Exception e) {
//            log.warn("写入码异常",e);
//        }

    }




}
